==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/mk-MK/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'За локациите',
    'about_locations'           => 'Локациите се користат за следење на информации за тоа каде се наоѓаат корисниците, основните средства и други средства',
    'assets_rtd'                => 'Основни средства', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Доделени основни средства',
    'id'                        => 'ID',
    'city'                      => 'Град',
    'state'                     => 'Република',
    'country'                   => 'Држава',
    'create'                    => 'Креирај локација',
    'update'                    => 'Ажурирај локација',
    'print_assigned'            => 'Print Assigned',
    'print_all_assigned'        => 'Печати задолжение',
    'name'                      => 'Име на локација',
    'address'                   => 'Адреса',
    'address2'                   => 'Address Line 2',
    'zip'                       => 'Поштенски код',
    'locations'                 => 'Локации',
    'parent'                    => 'Родител',
    'currency'                  => 'Валута на локација',
    'ldap_ou'                   => 'LDAP OU за пребарување',
    'user_name'                 => 'User Name',
    'department'                => 'Одделение',
    'location'                  => 'Локација',
    'asset_tag'                 => 'Assets Tag',
    'asset_name'                => 'Име',
    'asset_category'            => 'Категорија',
    'asset_manufacturer'        => 'Производител',
    'asset_model'               => 'Модел',
    'asset_serial'              => 'Сериски',
    'asset_location'            => 'Локација',
    'asset_checked_out'         => 'Задолжен на',
    'asset_expected_checkin'    => 'Expected Checkin',
    'date'                      => 'Датум:',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'Signed By (Asset Auditor):',
    'signed_by_finance_auditor' => 'Signed By (Finance Auditor):',
    'signed_by_location_manager' => 'Signed By (Location Manager):',
    'signed_by'                 => 'Signed Off By:',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/mk-MK/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'За локациите',
    'about_locations'           => 'Локациите се користат за следење на информации за тоа каде се наоѓаат корисниците, основните средства и други средства',
    'assets_rtd'                => 'Основни средства', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Доделени основни средства',
    'id'                        => 'ID',
    'city'                      => 'Град',
    'state'                     => 'Република',
    'country'                   => 'Држава',
    'create'                    => 'Креирај локација',
    'update'                    => 'Ажурирај локација',
    'print_assigned'            => 'Доделено печатење',
    'print_all_assigned'        => 'Печати задолжение',
    'name'                      => 'Име на локација',
    'address'                   => 'Адреса',
    'address2'                   => 'Адреса 2',
    'zip'                       => 'Поштенски код',
    'locations'                 => 'Локации',
    'parent'                    => 'Родител',
    'currency'                  => 'Валута на локација',
    'ldap_ou'                   => 'LDAP OU за пребарување',
    'user_name'                 => 'Корисничко име',
    'department'                => 'Одделение',
    'location'                  => 'Локација',
    'asset_tag'                 => 'Ознака на средство',
    'asset_name'                => 'Име',
    'asset_category'            => 'Категорија',
    'asset_manufacturer'        => 'Производител',
    'asset_model'               => 'Модел',
    'asset_serial'              => 'Сериски',
    'asset_location'            => 'Локација',
    'asset_checked_out'         => 'Задолжен на',
    'asset_expected_checkin'    => 'Очекуван раздолжување',
    'date'                      => 'Датум:',
    'phone'                     => 'Телефон на локација',
    'signed_by_asset_auditor'   => 'Потпишано од (Ревизор на средства):',
    'signed_by_finance_auditor' => 'Потпишано од (Финансиски ревизор):',
    'signed_by_location_manager' => 'Потпишано од (Менаџер за локација):',
    'signed_by'                 => 'Потпишано од:',
];
